@@ -34,6 +34,7 @@ from lib389.instance.options import General2Base, Slapd2Base, Backend2Base
 from lib389.paths import Paths
 from lib389.saslmap import SaslMappings
 from lib389.instance.remove import remove_ds_instance
+from lib389.index import Indexes
 from lib389.utils import (
     assert_c,
     is_a_dn,
@@ -567,6 +568,15 @@ class SetupDs(object):
 
         # We need to know the prefix before we can do the instance checks
         assert_c(slapd['instance_name'] is not None, "Configuration instance_name in section [slapd] not found")
+        assert_c(len(slapd['instance_name']) <= 80, "Server identifier should not be longer than 80 symbols")
+        assert_c(all(ord(c) < 128 for c in slapd['instance_name']), "Server identifier can not contain non ascii characters")
+        assert_c(' ' not in slapd['instance_name'], "Server identifier can not contain a space")
+        assert_c(slapd['instance_name'] != 'admin', "Server identifier \"admin\" is reserved, please choose a different identifier")
+
+        # Check that valid characters are used
+        safe = re.compile(r'^[:\w@_-]+$').search
+        assert_c(bool(safe(slapd['instance_name'])), "Server identifier has invalid characters, please choose a different value")
+
         # Check if the instance exists or not.
         # Should I move this import? I think this prevents some recursion
         from lib389 import DirSrv
@@ -661,11 +671,10 @@ class SetupDs(object):
                 self._install_ds(general, slapd, backends)
             except ValueError as e:
                 if DEBUGGING is False:
-                    self.log.fatal("Error: " + str(e) + ", removing incomplete installation...")
                     self._remove_failed_install(slapd['instance_name'])
                 else:
-                    self.log.fatal("Error: " + str(e) + ", preserving incomplete installation for analysis...")
-                raise ValueError("Instance creation failed!")
+                    self.log.fatal(f"Error: {str(e)}, preserving incomplete installation for analysis...")
+                raise ValueError(f"Instance creation failed!  {str(e)}")
 
             # Call the child api to do anything it needs.
             self._install(extra)
@@ -796,7 +805,9 @@ class SetupDs(object):
             args = ' '.join(ensure_list_str(result.args))
             stdout = ensure_str(result.stdout)
             stderr = ensure_str(result.stderr)
-            self.log.debug(f"CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}")
+            # Systemd encodes some odd charecters into it's symlink output on newer versions which
+            # can trip up the logger.
+            self.log.debug(f"CMD: {args} ; STDOUT: {stdout} ; STDERR: {stderr}".encode("utf-8"))
 
             # Setup tmpfiles_d
             tmpfile_d = ds_paths.tmpfiles_d + "/dirsrv-" + slapd['instance_name'] + ".conf"
@@ -823,7 +834,16 @@ class SetupDs(object):
         if self.containerised:
             ds_instance.systemd_override = general['systemd']
 
+        # By default SUSE does something extremely silly - it creates a hostname
+        # that CANT be resolved by DNS. As a result this causes all installs to
+        # fail. We need to guarantee that we only connect to localhost here, as
+        # it's the only stable and guaranteed way to connect to the instance
+        # at this point.
+        #
+        # Alternately, we could use ldapi instead, which would prevent the need
+        # to configure a temp root pw in the setup phase.
         args = {
+            SER_HOST: "localhost",
             SER_PORT: slapd['port'],
             SER_SERVERID_PROP: slapd['instance_name'],
             SER_ROOT_DN: slapd['root_dn'],
@@ -899,6 +919,19 @@ class SetupDs(object):
         if slapd['self_sign_cert']:
             ds_instance.config.set('nsslapd-security', 'on')
 
+        # Before we create any backends, create any extra default indexes that may be
+        # dynamicly provisioned, rather than from template-dse.ldif. Looking at you
+        # entryUUID (requires rust enabled).
+        #
+        # Indexes defaults to default_index_dn
+        indexes = Indexes(ds_instance)
+        if ds_instance.ds_paths.rust_enabled:
+            indexes.create(properties={
+                'cn': 'entryUUID',
+                'nsSystemIndex': 'false',
+                'nsIndexType': ['eq', 'pres'],
+            })
+
         # Create the backends as listed
         # Load example data if needed.
         for backend in backends:
